@@ -1,7 +1,7 @@
 pub use log::{Level, LevelFilter, Log};
 pub use termcolor::{Color, ColorChoice};
 
-pub use self::config::{format_description, Config, ConfigBuilder, FormatItem, TimeFormat};
+pub use self::config::{format_description, Config, ConfigBuilder, FormatItem, FormatText, TimeFormat};
 pub use self::loggers::{CombinedLogger, SimpleLogger, TermLogger, TerminalMode, WriteLogger};
 
 mod common;
